# msprime

[![Build Status](https://travis-ci.org/tskit-dev/msprime.svg?branch=master)](https://travis-ci.org/tskit-dev/msprime) [![Build status](https://ci.appveyor.com/api/projects/status/3d4rhxw6wxgm9snj/branch/master?svg=true)](https://ci.appveyor.com/project/tskit-dev/msprime/branch/master) [![CircleCI](https://circleci.com/gh/tskit-dev/msprime.svg?style=svg)](https://circleci.com/gh/tskit-dev/msprime) [![codecov](https://codecov.io/gh/tskit-dev/msprime/branch/master/graph/badge.svg)](https://codecov.io/gh/tskit-dev/msprime) [![Documentation Status](https://readthedocs.org/projects/msprime/badge/?version=stable)](https://msprime.readthedocs.io/en/stable/?badge=stable)

``msprime`` is a Python API and command line interface for simulating the 
coalescent with recombination. Please see the 
[documentation](https://msprime.readthedocs.org/en/latest/)
for further information and 
[installation instructions](https://msprime.readthedocs.org/en/latest/installation.html).

If you would like to help make ``msprime`` better, please see the 
[developer documentation](https://msprime.readthedocs.org/en/latest/development.html)
to get started.

If you are looking for help on a specific issue or would like to ask a
question to fellow ``msprime`` users, please send an email to the
[mailing list](https://groups.google.com/group/msprime-users). By asking
questions on the mailing list, you can help to build a searchable knowledge
base.

If you use ``msprime`` in your work, please cite the [PLOS Computational
Biology](http://dx.doi.org/10.1371/journal.pcbi.1004842) paper.
See [here](https://msprime.readthedocs.org/en/latest/CITATION.html) for
full citation details.


## NOTE FOR DEVELOPERS

The codebase is currently in a transitional phase, where ``tskit`` and ``msprime`` are being 
separated. As a result, some documentation is inaccurate and there are a lot of rough edges.
Everything will be cleaned up nicely for the next release of the packages. In the meantime,
thanks for your patience!
